Notebook Example
===============================================================================

:download:`notebook.enaml <../../../examples/widgets/notebook.enaml>`

.. literalinclude:: ../../../examples/widgets/notebook.enaml
    :language: python

::

 $ enaml-run notebook.enaml

.. image:: images/notebook1.png
.. image:: images/notebook2.png
.. image:: images/notebook3.png
